@@ -6,7 +6,7 @@ Lingua::YaTeA - Perl extension for extracting terms from a corpus and providing
 
 =head1 SYNOPSIS
 
-use Lingua::YaTeA;
+use Lingua::YaTeA::YaTeA;
 
 my %config = Lingua::YaTeA::load_config($rcfile);
 
@@ -20,19 +20,17 @@ $yatea->termExtraction($corpus);
 =head1 DESCRIPTION
 
 This module is the main module of the software named YaTeA. It aims at
-extracting noun phrases that look like terms from a corpus.  It
-provides their syntactic analysis in a head-modifier representation.
-As an input, the term extractor requires a corpus which has been
-segmented into words and sentences, lemmatized and tagged with
-part-of-speech (POS) information. The input file is encoded in
-UTF-8. The implementation of this term extractor allows to process
-large corpora.  Data provided with YaTeA allow to extract terms from
-English and French texts.  But new linguistic features can be
-integrated to extract terms from another language. Moreover,
+extracting noun phrases that look like terms from a corpus. It
+provides their syntactic analysis in a head-modifier format.  As an
+input, the term extractor requires a corpus which has been segmented
+into words and sentences, lemmatized and tagged with part-of-speech
+(POS) information. The implementation of this term extractor allows to
+process large corpora.  Data provided with YaTeA allow to extract
+terms from English and French texts.  But new linguistic features can
+be integrated to extract terms from another language. Moreover,
 linguistic features can be modified or created for a sub-language or
 tagset.
 
-For the use of YaTeA, see the documentation with the script C<yatea>.
 
 The main strategy of analysis of the term candidates is based on the
 exploitation of simple parsing patterns and endogenous
@@ -40,7 +38,7 @@ disambiguation. Exogenous disambiguation is also made possible for the
 identification and the analysis of term candidates by the use of
 external resources, I<i.e.> lists of testified terms.
 
-=head2 ANALYSIS: ENDOGENOUS AND EXOGENOUS DISAMBIGUATION
+=head2 ENDOGENOUS AND EXOGENOUS DISAMBIGUATION
 
 Endogenous disambiguation consists in the exploitation of intermediate
 chunking and parsing results for the parsing of a given Maximal Noun
@@ -244,15 +242,15 @@ The configuration file of YaTeA is divided into two sections:
 
 =item * 
 
-C<CONFIG_DIR> : directory containing the configuration files according to the language
+C<CONFIG_REP> : directory containing the configuration files according to the language
 
 =item * 
 
-C<LOCALE_DIR> : directory containing the environment files according to the language
+C<LOCALE_REP> : directory containing the environment files according to the language
 
 =item * 
 
-C<RESULT_DIR> : directory where are stored the results (probably not useful)
+C<RESULT_REP> : directory where are stored the results
 
 =back
 
@@ -262,12 +260,8 @@ C<RESULT_DIR> : directory where are stored the results (probably not useful)
 
 =item * 
 
-C<language> I<language> : Definition of the language of the
-corpus. Values are either C<FR> (French - TreeTagger output - TagSet
-<http://www.ims.uni-stuttgart.de/~schmid/french-tagset.html>),
-C<FR-Flemm> (French - output of Flemm analyser or C<EN> (English -
-TreeTagger or GeniaTagger output - PennTreeBank Tagset)
-
+C<lang> I<language> : Definition of the language of the corpus. Values
+are either C<FR> (French) or C<EN> (English)
 
 =item * 
 
@@ -373,23 +367,6 @@ term candidates with the value C<all>, or if any value is specified.
 
 =back
 
-=back
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item *
-
-Charlotte Roze has defined the configuration files to process a corpus
-tagged with Flemm
-
-=item * 
-
-Wiktoria Golik, Robert Bossy and Claire Nédellec (MIG/INRA) have
-corrected bugs and improve the mapping of testified terms.
-
-
 =back
 
 =head1 SEE ALSO
@@ -402,7 +379,7 @@ Terminological Resources. In Advances in Natural Language Processing
 
 =head1 AUTHORS
 
-Thierry Hamon <thierry.hamon@univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
+Thierry Hamon <thierry.hamon@lipn.univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
 
 =head1 LICENSE
 
@@ -416,8 +393,8 @@ at your option, any later version of Perl 5 you may have available.
 =cut
 
 use strict;
-use warnings;
 use Data::Dumper;
+
 use Lingua::YaTeA::ParsingPatternRecordSet;
 use Lingua::YaTeA::OptionSet;
 use Lingua::YaTeA::Option;
@@ -429,7 +406,7 @@ use Lingua::YaTeA::ForbiddenStructureSet;
 use Lingua::YaTeA::PhraseSet;
 use Lingua::YaTeA::TestifiedTermSet;
 
-our $VERSION='0.6.1';
+our $VERSION='0.2';
 
 our $process_counter = 1;
 
@@ -437,11 +414,11 @@ sub load_config
 {
 
     my ($rcfile) = @_;
-    
+ 
 # Read de configuration file
 
     if ((! defined $rcfile) || ($rcfile eq "")) {
-	$rcfile = "/etc/yatea/yatea.rc";    
+	$rcfile = "/etc/yatea/yatea.rc";
     }
     
     my $conf = new Config::General('-ConfigFile' => $rcfile,
@@ -489,28 +466,26 @@ sub new
 sub termExtraction
 {
     my ($this,$corpus) = @_;
+    
     my $sentence_boundary = $this->getOptionSet->getSentenceBoundary;
     my $document_boundary = $this->getOptionSet->getDocumentBoundary;
-    my $debug_fh = FileHandle->new(">".$corpus->getOutputFileSet->getFile('debug')->getPath);;
-    binmode($debug_fh, ":utf8");
+
     $this->loadTestifiedTerms(\$process_counter,$corpus,$sentence_boundary,$document_boundary,$this->getOptionSet->MatchTypeValue,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage);
     
+    
 
     print STDERR $process_counter++ . ") " . ($this->getMessageSet->getMessage('LOAD_CORPUS')->getContent($this->getOptionSet->getDisplayLanguage)) . "\n";
 
     
-#    warn "Language: " . $this->getOptionSet->getLanguage . "\n";
 
-    $corpus->read($sentence_boundary,$document_boundary,$this->getFSSet,$this->getTestifiedTermSet,$this->getOptionSet->MatchTypeValue,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage, $this->getOptionSet->getLanguage,$debug_fh);
+    $corpus->read($sentence_boundary,$document_boundary,$this->getFSSet,$this->getTestifiedTermSet,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage);
     
     my $phrase_set = Lingua::YaTeA::PhraseSet->new;
     
     print STDERR $process_counter++ . ") " . ($this->getMessageSet->getMessage('CHUNKING')->getContent($this->getOptionSet->getDisplayLanguage)) . "\n";
-    $corpus->chunk($phrase_set,$sentence_boundary,$document_boundary,$this->getChunkingDataSet,$this->getFSSet,$this->getTagSet,$this->getParsingPatternSet,$this->getTestifiedTermSet,$this->getOptionSet,$debug_fh);
+    $corpus->chunk($phrase_set,$sentence_boundary,$document_boundary,$this->getChunkingDataSet,$this->getFSSet,$this->getTagSet,$this->getParsingPatternSet,$this->getTestifiedTermSet,$this->getOptionSet);
 
-    my $fh = FileHandle->new(">".$corpus->getOutputFileSet->getFile('unparsed')->getPath);
-    binmode($fh, ":utf8");
-    $phrase_set->printPhrases($fh);
+    $phrase_set->printPhrases($corpus->getOutputFileSet->getFile('unparsed'));
 
 #     print STDERR Dumper($phrase_set);
 
@@ -521,7 +496,8 @@ sub termExtraction
 	
 	print STDERR $process_counter++ . ") " . ($this->getMessageSet->getMessage('PARSING')->getContent($this->getOptionSet->getDisplayLanguage)) . "\n";
 	
-	$phrase_set->parseProgressively($this->getTagSet,$this->getOptionSet->getParsingDirection,$this->getParsingPatternSet,$this->getChunkingDataSet,$corpus->getLexicon,$corpus->getSentenceSet,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage,$debug_fh);
+	my $fh = FileHandle->new(">".$corpus->getOutputFileSet->getFile('debug')->getPath);
+	$phrase_set->parseProgressively($this->getTagSet,$this->getOptionSet->getParsingDirection,$this->getParsingPatternSet,$this->getChunkingDataSet,$corpus->getLexicon,$corpus->getSentenceSet,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage,$fh);
 	
 	$phrase_set->printParsingStatistics($this->getMessageSet,$this->getOptionSet->getDisplayLanguage);
 	
@@ -540,14 +516,12 @@ sub termExtraction
 	    )
 	{
 	    $phrase_set->addTermCandidates($this->getOptionSet);
-	    $corpus->makeDDW($phrase_set->getTermCandidates,$debug_fh);
 	}
     }
     
     print STDERR $process_counter++ . ") " . ($this->getMessageSet->getMessage('RESULTS')->getContent($this->getOptionSet->getDisplayLanguage)) . "\n";
     
-    $this->displayExtractionResults($phrase_set,$corpus,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage,$this->getOptionSet->getDefaultOutput,$debug_fh);
-    return(0);
+    $this->displayExtractionResults($phrase_set,$corpus,$this->getMessageSet,$this->getOptionSet->getDisplayLanguage,$this->getOptionSet->getDefaultOutput);
 }
 
 
@@ -570,7 +544,7 @@ sub setConfigFiles
     my $config_files;
     my $language = $this->getOptionSet->getLanguage;
 #    print STDERR Dumper(%$system_config_h);
-    my $repository = $system_config_h->{'DefaultConfig'}->{CONFIG_DIR} . "/" . $language;
+    my $repository = $system_config_h->{'DefaultConfig'}->{CONFIG_REP} . "/" . $language;
    
     my @file_names = ("Options","ForbiddenStructures","ChunkingFrontiers","ChunkingExceptions","CleaningFrontiers","CleaningExceptions","ParsingPatterns","TagSet","LGPmapping");
 
@@ -586,7 +560,7 @@ sub setLocaleFiles
 {
     my ($this,$system_config_h) = @_;
     my $config_files;
-    my $repository = $system_config_h->{'DefaultConfig'}->{LOCALE_DIR} . "/";
+    my $repository = $system_config_h->{'DefaultConfig'}->{LOCALE_REP} . "/";
     my @file_names = ("Messages");
     
     $this->{LOCALE_FILE_SET} = Lingua::YaTeA::FileSet->new($repository);
@@ -625,6 +599,7 @@ sub setParsingPatterns
 #    print STDERR "Parsing Patterns loaded\n";
 }
 
+
 sub setChunkingDataSet
 {
     my ($this) = @_;
@@ -773,14 +748,14 @@ sub addMessageSetFile
 
 sub displayExtractionResults
 {
-    my ($this,$phrase_set,$corpus,$message_set,$display_language,$default_output,$debug_fh) = @_;
+    my ($this,$phrase_set,$corpus,$message_set,$display_language,$default_output) = @_;
 
     
     
     if ((defined $this->getOptionSet->getOption('debug')) && ($this->getOptionSet->getOption('debug')->getValue() == 1))
     {
 	print STDERR "\t-" . ($this->getMessageSet->getMessage('DISPLAY_RAW')->getContent($this->getOptionSet->getDisplayLanguage)) . "\'". $corpus->getOutputFileSet->getFile('debug')->getPath . "'\n";
-	$phrase_set->printPhrases($debug_fh);
+	$phrase_set->printPhrases($corpus->getOutputFileSet->getFile('debug'));
 	$phrase_set->printUnparsable($corpus->getOutputFileSet->getFile('unparsable'));
 #	$phrase_set->printUnparsed($corpus->getOutputFileSet->getFile('unparsed'));
     }
@@ -799,7 +774,6 @@ sub displayExtractionResults
     if ((defined $this->getOptionSet->getOption('printChunking')) && ($this->getOptionSet->getOption('printChunking')->getValue() == 1))
     {
 	print STDERR "\t-" . ($this->getMessageSet->getMessage('DISPLAY_CORPUS_PHRASES')->getContent($this->getOptionSet->getDisplayLanguage)) . "\'". $corpus->getOutputFileSet->getFile('candidatesAndUnparsedInCorpus')->getPath . "'\n";
-	
 	$corpus->printCandidatesAndUnparsedInCorpus($phrase_set->getTermCandidates,$phrase_set->getUnparsable,$corpus->getOutputFileSet->getFile('candidatesAndUnparsedInCorpus'),$this->getOptionSet->getSentenceBoundary,$this->getOptionSet->getDocumentBoundary,$this->getOptionSet->getOption('COLOR_BLIND'));
     }
 
@@ -834,19 +808,6 @@ sub displayExtractionResults
 	print STDERR "\t-" . ($this->getMessageSet->getMessage('TTG_TERM_CANDIDATES')->getContent($this->getOptionSet->getDisplayLanguage)) . "\'". $corpus->getOutputFileSet->getFile('termCandidates')->getPath . "'\n";
 	$phrase_set->printTermCandidatesTTG($corpus->getOutputFileSet->getFile("termCandidates"),$this->getOptionSet->getTTGStyle);
     } 
-
-     if (defined $this->getOptionSet->getOption('bootstrap'))
-     {
-	 print STDERR "\t-" . ($this->getMessageSet->getMessage('DISPLAY_BOOTSTRAP')->getContent($this->getOptionSet->getDisplayLanguage)) . "\'". $corpus->getOutputFileSet->getFile('parsedTerms')->getPath . "'\n";
-	$phrase_set->printBootstrapList($corpus->getOutputFileSet->getFile('parsedTerms'),$corpus->getName);
-     }
-    if ((defined $this->getOptionSet->getOption('XML-corpus-raw')) && ($this->getOptionSet->getOption('XML-corpus-raw')->getValue() == 1))
-    {
-	print STDERR "\t-" . ($this->getMessageSet->getMessage('DISPLAY_CORPUS_RAW')->getContent($this->getOptionSet->getDisplayLanguage)) . "\'". $corpus->getOutputFileSet->getFile('corpusRaw')->getPath . "'\n";
-	
-	$corpus->printXMLRawCorpus($corpus->getOutputFileSet->getFile('corpusRaw'),$this->getOptionSet->getSentenceBoundary,$this->getOptionSet->getDocumentBoundary);
-    }
-    return(0);
 }
 
 
